"""urlwatch monitors webpages for you

urlwatch is intended to help you watch changes in webpages and get notified
(via e-mail, in your terminal or through various third party services) of any
changes. The change notification will include the URL that has changed and
a unified diff of what has changed.
"""

pkgname = 'urlwatch'

__copyright__ = 'Copyright 2008-2019 Thomas Perl'
__author__ = 'Thomas Perl <m@thp.io>'
__license__ = 'BSD'
__url__ = 'https://thp.io/2008/urlwatch/'
__version__ = '2.16'
__user_agent__ = '%s/%s (+https://thp.io/2008/urlwatch/info.html)' % (pkgname, __version__)
